.. image:: images/libE_logo.png
 :alt: libEnsemble

.. only::html
  |

  .. image:: https://img.shields.io/pypi/v/libensemble.svg?color=blue
    :target: https://pypi.org/project/libensemble

  .. image:: https://github.com/Libensemble/libensemble/workflows/init-libEnsemble-CI/badge.svg?branch=develop
    :target: https://github.com/Libensemble/libensemble/actions

  .. image:: https://coveralls.io/repos/github/Libensemble/libensemble/badge/?maxAge=2592000/?branch=master
    :target: https://coveralls.io/github/Libensemble/libensemble?branch=master

  .. image::  https://readthedocs.org/projects/libensemble/badge/?maxAge=2592000
    :target: https://libensemble.readthedocs.org/en/latest/
    :alt: Documentation Status

  |

=======================================
Welcome to libEnsemble's documentation!
=======================================

libEnsemble is a library to coordinate the concurrent evaluation of dynamic ensembles of calculations.

* New to libEnsemble? Start :doc:`here<introduction>`.
* Try out libEnsemble with a :doc:`tutorial<tutorials/local_sine_tutorial>`.
* Go in depth by reading the :doc:`Overview<overview_usecases>`.
* See the :doc:`FAQ<FAQ>` for common questions and answers, errors, and resolutions.
* Check us out on `GitHub`_.

**Users interested in updating to v0.8.0+ should read the** `Updating for libEnsemble v0.8.0`_ **wiki.**

.. _GitHub: https://github.com/Libensemble/libensemble
.. _Updating for libEnsemble v0.8.0: https://github.com/Libensemble/libensemble/wiki/Updating-for-libEnsemble-v0.8.0
